@@ -651,7 +651,7 @@ static void mutt_set_default (struct option_t *p)
       if (!p->init && *((char **) p->data))
       {
 	char *cp = safe_strdup (*((char **) p->data));
-	mutt_pretty_mailbox (cp);
+	/* mutt_pretty_mailbox (cp); */
         p->init = (unsigned long) cp;
       }
       break;
@@ -1330,7 +1330,6 @@ finish:
 }
 
 
-#define MAX(a,b) (((a) >= (b)) ? (a) : (b))
 #define NUMVARS (sizeof (MuttVars)/sizeof (MuttVars[0]))
 #define NUMCOMMANDS (sizeof (Commands)/sizeof (Commands[0]))
 /* initial string that starts completion. No telling how much crap 
