@@ -23,6 +23,9 @@
 #ifdef HAVE_UNISTD_H
 # include <unistd.h> /* needed for SEEK_SET */
 #endif
+#ifdef HAVE_UNIX_H
+# include <unix.h>   /* needed for snprintf on QNX. */
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
@@ -625,7 +628,7 @@ typedef struct header
 #endif
 
 #ifdef USE_IMAP
-  void *data;            /* driver-specific data (only used by IMAP */
+  void *data;            /* driver-specific data (only used by IMAP) */
 #endif
 } HEADER;
 
