@@ -22,7 +22,7 @@
 #include "globals.h"
 #include "mutt_socket.h"
 #ifdef USE_SSL
-# include "imap_ssl.h"
+# include "mutt_ssl.h"
 #endif
 
 #include <unistd.h>
@@ -49,9 +49,13 @@ int mutt_socket_open (CONNECTION* conn)
 
 int mutt_socket_close (CONNECTION* conn)
 {
-  int rc;
+  int rc = -1;
+
+  if (conn->fd < 0)
+    dprint (1, (debugfile, "mutt_socket_close: Attempt to close closed connection.\n"));
+  else
+    rc = conn->close (conn);
 
-  rc = conn->close (conn);
   conn->fd = -1;
 
   return rc;
@@ -59,9 +63,25 @@ int mutt_socket_close (CONNECTION* conn)
 
 int mutt_socket_write_d (CONNECTION *conn, const char *buf, int dbg)
 {
+  int rc;
+
   dprint (dbg, (debugfile,"> %s", buf));
 
-  return conn->write (conn, buf);
+  if (conn->fd < 0)
+  {
+    dprint (1, (debugfile, "mutt_socket_write: attempt to write to closed connection\n"));
+    return -1;
+  }
+
+  if ((rc = conn->write (conn, buf, mutt_strlen (buf))) < 0)
+  {
+    dprint (1, (debugfile, "mutt_socket_write: error writing, closing socket\n"));
+    mutt_socket_close (conn);
+
+    return -1;
+  }
+
+  return rc;
 }
 
 /* simple read buffering to speed things up. */
@@ -69,7 +89,13 @@ int mutt_socket_readchar (CONNECTION *conn, char *c)
 {
   if (conn->bufpos >= conn->available)
   {
-    conn->available = conn->read (conn);
+    if (conn->fd >= 0)
+      conn->available = conn->read (conn);
+    else
+    {
+      dprint (1, (debugfile, "mutt_socket_readchar: attempt to read closed from connection.\n"));
+      return -1;
+    }
     conn->bufpos = 0;
     if (conn->available <= 0)
       return conn->available; /* returns 0 for EOF or -1 for other error */
@@ -88,7 +114,6 @@ int mutt_socket_readln_d (char* buf, size_t buflen, CONNECTION* conn, int dbg)
   {
     if (mutt_socket_readchar (conn, &ch) != 1)
     {
-      dprint (1, (debugfile, "mutt_socket_readln_d: read error"));
       buf[i] = '\0';
       return -1;
     }
@@ -99,13 +124,14 @@ int mutt_socket_readln_d (char* buf, size_t buflen, CONNECTION* conn, int dbg)
 
   /* strip \r from \r\n termination */
   if (i && buf[i-1] == '\r')
-    buf[i-1] = '\0';
+    buf[--i] = '\0';
   else
     buf[i] = '\0';
 
   dprint (dbg, (debugfile, "< %s\n", buf));
   
-  return i+1;
+  /* number of bytes read, not strlen */
+  return i + 1;
 }
 
 CONNECTION* mutt_socket_head (void)
@@ -165,11 +191,19 @@ CONNECTION* mutt_conn_find (const CONNECTION* start, const ACCOUNT* account)
   conn->next = Connections;
   Connections = conn;
 
-#ifdef USE_SSL
   if (account->flags & M_ACCT_SSL) 
+  {
+#ifdef USE_SSL
     ssl_socket_setup (conn);
-  else
+#else
+    mutt_error _("SSL is unavailable.");
+    sleep (2);
+    FREE (&conn);
+
+    return NULL;
 #endif
+  }
+  else
   {
     conn->read = raw_socket_read;
     conn->write = raw_socket_write;
@@ -230,9 +264,9 @@ int raw_socket_read (CONNECTION *conn)
   return read (conn->fd, conn->inbuf, LONG_STRING);
 }
 
-int raw_socket_write (CONNECTION *conn, const char *buf)
+int raw_socket_write (CONNECTION* conn, const char* buf, size_t count)
 {
-  return write (conn->fd, buf, mutt_strlen (buf));
+  return write (conn->fd, buf, count);
 }
 
 int raw_socket_open (CONNECTION* conn)
