@@ -24,7 +24,7 @@
 #include "mailbox.h"
 #include "copy.h"
 #include "keymap.h"
-
+#include "url.h"
 
 #ifdef HAVE_PGP
 #include "pgp.h"
@@ -313,7 +313,19 @@ void mx_unlink_empty (const char *path)
 
 int mx_is_imap(const char *p)
 {
-  return p && (*p == '{');
+  url_scheme_t scheme;
+
+  if (!p)
+    return 0;
+
+  if (*p == '{')
+    return 1;
+
+  scheme = url_check_scheme (p);
+  if (scheme == U_IMAP || scheme == U_IMAPS)
+    return 1;
+
+  return 0;
 }
 
 #endif
@@ -1037,6 +1049,7 @@ int mx_sync_mailbox (CONTEXT *ctx, int *index_hint)
 {
   int rc, i;
   int purge = 1;
+  int msgcount, deleted;
 
   if (ctx->dontwrite)
   {
@@ -1087,6 +1100,11 @@ int mx_sync_mailbox (CONTEXT *ctx, int *index_hint)
     }
   }
 
+  /* really only for IMAP - imap_sync_mailbox results in a call to
+   * mx_update_tables, so ctx->deleted is 0 when it comes back */
+  msgcount = ctx->msgcount;
+  deleted = ctx->deleted;
+
 #ifdef USE_IMAP
   if (ctx->magic == M_IMAP)
     rc = imap_sync_mailbox (ctx, purge, index_hint);
@@ -1097,11 +1115,11 @@ int mx_sync_mailbox (CONTEXT *ctx, int *index_hint)
   {
 #ifdef USE_IMAP
     if (ctx->magic == M_IMAP && !purge)
-      mutt_message (_("Mailbox checkpointed."), ctx->msgcount);
+      mutt_message _("Mailbox checkpointed.");
     else
 #endif
-    mutt_message (_("%d kept, %d deleted."), ctx->msgcount - ctx->deleted,
-      ctx->deleted);
+    mutt_message (_("%d kept, %d deleted."), msgcount - deleted,
+      deleted);
 
     sleep (1); /* allow the user time to read the message */
 
@@ -1118,15 +1136,13 @@ int mx_sync_mailbox (CONTEXT *ctx, int *index_hint)
     if (purge)
     {
 #ifdef USE_IMAP
-      /* IMAP uses the active flag, since deleted messages may remain after
-       * a sync */
-      if (ctx->magic == M_IMAP)
-	mx_update_tables (ctx, 0);
-      else
+      /* IMAP does this automatically after handling EXPUNGE */
+      if (ctx->magic != M_IMAP)
 #endif
+      {
 	mx_update_tables (ctx, 1);
-
-      mutt_sort_headers (ctx, 1); /* rethread from scratch */
+	mutt_sort_headers (ctx, 1); /* rethread from scratch */
+      }
     }
   }
 
