@@ -674,7 +674,7 @@ static size_t convert_file_to (FILE *file, const char *fromcode,
   CONTENT_STATE *states;
   size_t *score;
 
-  cd1 = iconv_open ("UTF-8", fromcode);
+  cd1 = mutt_iconv_open ("UTF-8", fromcode);
   if (cd1 == (iconv_t)(-1))
     return -1;
 
@@ -688,7 +688,7 @@ static size_t convert_file_to (FILE *file, const char *fromcode,
   memset (infos, 0, ncodes * sizeof (CONTENT));
   for (i = 0; i < ncodes; i++)
     if (strcasecmp (tocodes[i], "UTF-8"))
-      cd[i] = iconv_open (tocodes[i], "UTF-8");
+      cd[i] = mutt_iconv_open (tocodes[i], "UTF-8");
     else
       /* Special case for conversion to UTF-8 */
       cd[i] = (iconv_t)(-1), score[i] = (size_t)(-1);
@@ -890,6 +890,7 @@ CONTENT *mutt_get_content_info (const char *fname, BODY *b)
   FILE *fp = NULL;
   char *tocode;
   char buffer[100];
+  char chsbuf[STRING];
   size_t r;
 
   if(b && !fname) fname = b->filename;
@@ -912,7 +913,10 @@ CONTENT *mutt_get_content_info (const char *fname, BODY *b)
 			      0, &tocode, info) != (size_t)(-1))
     {
       if (!chs)
+      {
+	mutt_canonical_charset (chsbuf, sizeof (chsbuf), tocode);
 	mutt_set_parameter ("charset", tocode, &b->parameter);
+      }
       safe_free ((void **) &tocode);
       safe_fclose (&fp);
       return info;
@@ -928,7 +932,7 @@ CONTENT *mutt_get_content_info (const char *fname, BODY *b)
   
   if (b != NULL && b->type == TYPETEXT && (!b->noconv && !b->force_charset))
     mutt_set_parameter ("charset", (!info->hibin ? "us-ascii" :
-				    Charset ? Charset : "unknown-8bit"),
+				    Charset  && !mutt_is_us_ascii (Charset) ? Charset : "unknown-8bit"),
 			&b->parameter);
 
   return info;
@@ -1159,7 +1163,7 @@ static void mutt_set_encoding (BODY *b, CONTENT *info)
   if (b->type == TYPETEXT)
   {
     char *chsname = mutt_get_body_charset (send_charset, sizeof (send_charset), b);
-    if ((info->lobin && strncasecmp (chsname, "iso-2022-jp", 11)) || info->linemax > 990 || (info->from && option (OPTENCODEFROM)))
+    if ((info->lobin && strncasecmp (chsname, "iso-2022", 8)) || info->linemax > 990 || (info->from && option (OPTENCODEFROM)))
       b->encoding = ENCQUOTEDPRINTABLE;
     else if (info->hibin)
       b->encoding = option (OPTALLOW8BIT) ? ENC8BIT : ENCQUOTEDPRINTABLE;
@@ -1210,7 +1214,7 @@ char *mutt_get_body_charset (char *d, size_t dlen, BODY *b)
     p = mutt_get_parameter ("charset", b->parameter);
 
   if (p)
-    strfcpy (d, NONULL(p), dlen);
+    mutt_canonical_charset (d, dlen, NONULL(p));
   else
     strfcpy (d, "us-ascii", dlen);
 
@@ -1225,7 +1229,7 @@ void mutt_update_encoding (BODY *a)
   char chsbuff[STRING];
 
   /* override noconv when it's us-ascii */
-  if (!mutt_strcasecmp (mutt_get_body_charset (chsbuff, sizeof (chsbuff), a), "us-ascii"))
+  if (mutt_is_us_ascii (mutt_get_body_charset (chsbuff, sizeof (chsbuff), a)))
     a->noconv = 0;
 
   if (!a->force_charset && !a->noconv)
@@ -2068,11 +2072,11 @@ void mutt_prepare_envelope (ENVELOPE *env, int final)
   }
 
   /* Take care of 8-bit => 7-bit conversion. */
-  rfc2047_encode_adrlist (env->to);
-  rfc2047_encode_adrlist (env->cc);
-  rfc2047_encode_adrlist (env->from);
-  rfc2047_encode_adrlist (env->mail_followup_to);
-  rfc2047_encode_adrlist (env->reply_to);
+  rfc2047_encode_adrlist (env->to, "To");
+  rfc2047_encode_adrlist (env->cc, "Cc");
+  rfc2047_encode_adrlist (env->from, "From");
+  rfc2047_encode_adrlist (env->mail_followup_to, "Mail-Followup-To");
+  rfc2047_encode_adrlist (env->reply_to, "Reply-To");
 
   if (env->subject)
   {
@@ -2157,7 +2161,7 @@ void mutt_bounce_message (FILE *fp, HEADER *h, ADDRESS *to)
   if (fqdn)
     rfc822_qualify (from, fqdn);
 
-  rfc2047_encode_adrlist (from);
+  rfc2047_encode_adrlist (from, "Resent-From");
   
   rfc822_write_address (resent_from, sizeof (resent_from), from);
 
